WebVideoPlayer class

A widget that displays a simple video player for web platform.

Inheritance

Constructors

WebVideoPlayer({Key? key, String? url, String? path, bool autoPlay = false, bool isFullscreen = false, VideoPlayerController? videoController, Duration? seekDuration})
Creates a new web video player instance.
const

Properties

autoPlay → bool
if this is set to true, the video will start playing automatically.
final
hashCode → int
The hash code for this object.
no setterinherited
isFullscreen → bool
the video player will be fullscreen if this is set to true.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
path → String?
a path of the video to play, a valid path must be provided otherwise the player will not work.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seekDuration → Duration?
a seek duration to seek to when the player is initialized. this is useful when you want to seek to a specific duration when the player is initialized.
final
url → String?
a url of the video to play, a valid url must be provided otherwise the player will not work.
final
videoController → VideoPlayerController?
a custom video player controller, if this is provided, the player will use this controller instead of creating a new one.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<WebVideoPlayer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited